# RotaryPi

Python library to read the rotary dial of an old telephone with a Raspberry Pi.

Targets Python `>=3.9` on a Raspberry Pi.

This library was developed and tested on a PTT 50 wall-mounted telephone and a PTT 70 desktop telephone (both from Switzerland), but it should work with a wide variety of rotary dials since the basic principle is pretty strait forward and probably very similar on various models.

## Documentation

Read the full documentation on [readthedocs](https://rotarypi.readthedocs.io/en/latest/).
